*/*: sync with upstream

Taken from: HardenedBSD
This commit is contained in:
Franco Fichtner 2019-07-07 09:20:06 +02:00
parent 91581a23f2
commit 3450e915f5
1026 changed files with 7645 additions and 22207 deletions

View File

@ -14,7 +14,7 @@ LICENSE_NAME= UnRAR License
LICENSE_FILE= ${WRKSRC}/license.txt
LICENSE_PERMS= dist-mirror dist-sell pkg-mirror pkg-sell auto-accept
USES= gmake
USES= compiler:c++11-lang gmake
USE_LDCONFIG= yes
ALL_TARGET= lib

View File

@ -4,7 +4,7 @@
PORTNAME= libosmpbf
PORTVERSION= 1.3.3
DISTVERSIONPREFIX= v
PORTREVISION= 10
PORTREVISION= 11
CATEGORIES= astro geography devel
MAINTAINER= amdmi3@FreeBSD.org

View File

@ -3,7 +3,7 @@
PORTNAME= merkaartor
PORTVERSION= 0.18.2
PORTREVISION= 18
PORTREVISION= 19
CATEGORIES= astro
MAINTAINER= dev2@heesakkers.info

View File

@ -3,7 +3,7 @@
PORTNAME= alsa-plugins
PORTVERSION= 1.1.1
PORTREVISION= 4
PORTREVISION= 5
CATEGORIES= audio
MASTER_SITES= ftp://ftp.alsa-project.org/pub/plugins/ \
GENTOO
@ -15,8 +15,9 @@ LICENSE= LGPL21+
LIB_DEPENDS= libasound.so:audio/alsa-lib
GNU_CONFIGURE= yes
USES= alias libtool:keepla localbase pkgconfig tar:bzip2
GNU_CONFIGURE= yes
EXTRA_PATCHES+= ${FILESDIR}/alsa-plugins.patch
INSTALL_TARGET= install-strip
CPPFLAGS+= -I${.CURDIR}/../alsa-lib/files

View File

@ -1,4 +1,4 @@
--- oss/pcm_oss.c.orig 2016-07-26 13:27:23 UTC
--- oss/pcm_oss.c.orig 2019-07-04 14:37:07 UTC
+++ oss/pcm_oss.c
@@ -22,7 +22,11 @@
#include <sys/ioctl.h>
@ -12,7 +12,55 @@
#define ARRAY_SIZE(x) (sizeof(x) / sizeof(*(x)))
@@ -258,7 +262,7 @@ static int oss_drain(snd_pcm_ioplug_t *i
@@ -74,11 +78,19 @@ static snd_pcm_sframes_t oss_write(snd_p
size *= oss->frame_bytes;
result = write(oss->fd, buf, size);
#ifdef __FreeBSD__
- if (result == -1)
- return -errno;
+ if (result == -1) {
+ if (errno == EAGAIN)
+ return 0;
+ else
+ return -errno;
+ }
#else
- if (result <= 0)
- return result;
+ if (result <= 0) {
+ if (result == -EAGAIN)
+ return 0;
+ else
+ return result;
+ }
#endif
return result / oss->frame_bytes;
}
@@ -97,11 +109,19 @@ static snd_pcm_sframes_t oss_read(snd_pc
size *= oss->frame_bytes;
result = read(oss->fd, buf, size);
#ifdef __FreeBSD__
- if (result == -1)
- return -errno;
+ if (result == -1) {
+ if (errno == EAGAIN)
+ return 0;
+ else
+ return -errno;
+ }
#else
- if (result <= 0)
- return result;
+ if (result <= 0) {
+ if (result == -EAGAIN)
+ return 0;
+ else
+ return result;
+ }
#endif
return result / oss->frame_bytes;
}
@@ -258,10 +278,29 @@ static int oss_drain(snd_pcm_ioplug_t *i
#endif
if (io->stream == SND_PCM_STREAM_PLAYBACK)
@ -21,7 +69,29 @@
return 0;
}
@@ -272,7 +276,7 @@ static int oss_prepare(snd_pcm_ioplug_t
+static int oss_delay(snd_pcm_ioplug_t *io, snd_pcm_sframes_t *delayp)
+{
+ snd_pcm_oss_t *oss = io->private_data;
+ int tmp;
+
+ if (oss->fd < 0)
+ return -EBADFD;
+
+ if (io->stream == SND_PCM_STREAM_PLAYBACK) {
+ if (ioctl(oss->fd, SNDCTL_DSP_GETODELAY, &tmp) < 0 || tmp < 0)
+ tmp = 0;
+ } else {
+ tmp = 0;
+ }
+ *delayp = snd_pcm_bytes_to_frames(io->pcm, tmp);
+
+ return (0);
+}
+
#ifndef __FreeBSD__
static int oss_prepare(snd_pcm_ioplug_t *io)
{
@@ -272,7 +311,7 @@ static int oss_prepare(snd_pcm_ioplug_t
fprintf(stderr, "%s()\n", __func__);
#endif
@ -30,3 +100,56 @@
tmp = io->channels;
if (ioctl(oss->fd, SNDCTL_DSP_CHANNELS, &tmp) < 0) {
@@ -380,20 +419,26 @@ static int oss_hw_params(snd_pcm_ioplug_
ioctl(oss->fd, SNDCTL_DSP_RESET);
-#define blksz_aligned() ((1 << blksz_shift) - \
- ((1 << blksz_shift) % oss->frame_bytes))
- blksz_shift = 16;
- tmp = io->period_size * oss->frame_bytes;
+ /* use a 16ms HW buffer by default */
+ tmp = ((16 * io->rate) / 1000) * oss->frame_bytes;
- while (blksz_shift > 4 && blksz_aligned() > tmp)
- blksz_shift--;
+ /* round up to nearest power of two */
+ while (tmp & (tmp - 1))
+ tmp += tmp & ~(tmp - 1);
+
+ /* get logarithmic value */
+ for (blksz_shift = 0; blksz_shift < 24; blksz_shift++) {
+ if (tmp == (1 << blksz_shift))
+ break;
+ }
- blkcnt = 2;
tmp = io->buffer_size * oss->frame_bytes;
- while (blkcnt < 4096 && (blksz_aligned() * blkcnt) < tmp &&
- ((1 << blksz_shift) * blkcnt) < 131072)
- blkcnt <<= 1;
+ /* compute HW buffer big enough to hold SW buffer */
+ for (blkcnt = FREEBSD_OSS_BLKCNT_MIN; blkcnt != FREEBSD_OSS_BLKCNT_MAX; blkcnt *= 2) {
+ if ((blkcnt << blksz_shift) >= tmp)
+ break;
+ }
tmp = blksz_shift | (blkcnt << 16);
if (ioctl(oss->fd, SNDCTL_DSP_SETFRAGMENT, &tmp) < 0) {
@@ -767,6 +812,7 @@ static const snd_pcm_ioplug_callback_t o
.prepare = oss_prepare,
#endif
.drain = oss_drain,
+ .delay = oss_delay,
};
static const snd_pcm_ioplug_callback_t oss_capture_callback = {
@@ -780,6 +826,7 @@ static const snd_pcm_ioplug_callback_t o
.prepare = oss_prepare,
#endif
.drain = oss_drain,
+ .delay = oss_delay,
};

View File

@ -2,9 +2,9 @@
PORTNAME= amarok
DISTVERSIONPREFIX= v
DISTVERSION= 2.9.0-277
DISTVERSIONSUFFIX= -gd50ecc430c
PORTREVISION= 4
DISTVERSION= 2.9.70
PKGVERSIONSUFFIX= -g${GH_TAGNAME}
PORTREVISION= 0
CATEGORIES= audio kde
MAINTAINER= kde@FreeBSD.org
@ -30,7 +30,7 @@ USE_QT= core concurrent declarative dbus gui location network phonon4 \
webkit widgets xml \
buildtools_build qmake_build
USE_KDE= archive auth attica bookmarks codecs config configwidgets \
USE_KDE= archive auth attica bookmarks codecs config configwidgets \
completion coreaddons crash dbusaddons dnssd globalaccel \
guiaddons i18n iconthemes itemviews jobwidgets kdeclarative \
kcmutils kio kirigami2 newstuff notifications notifyconfig \
@ -42,6 +42,7 @@ USE_LDCONFIG= yes
USE_GITHUB= yes
GH_ACCOUNT= kde
GH_TAGNAME= 0aa6ae0c77
SHEBANG_FILES= src/kconf_update/amarok-2.4.1-tokens_syntax_update.pl
CMAKE_ARGS= -DOPENSSL_ROOT_DIR=${OPENSSLBASE}
@ -67,6 +68,7 @@ IPOD_CMAKE_BOOL= WITH_IPOD
MP3TUNES_DESC= MP3tunes support
MP3TUNES_LIB_DEPENDS= libloudmouth-1.so:net-im/loudmouth \
libcurl.so:ftp/curl
MP3TUNES_LIB_DEPENDS_OFF= libgcrypt.so:security/libgcrypt
MP3TUNES_USE= GNOME=glib20,libxml2
MP3TUNES_USES= gnome ssl

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1545825317
SHA256 (kde-amarok-v2.9.0-277-gd50ecc430c_GH0.tar.gz) = e1dc7d1fe11f88a4b71e69ebeb94b62c63db6f1f5ac52ddeed89d92343108e9f
SIZE (kde-amarok-v2.9.0-277-gd50ecc430c_GH0.tar.gz) = 21062595
TIMESTAMP = 1558016091
SHA256 (kde-amarok-v2.9.70-0aa6ae0c77_GH0.tar.gz) = 2c236fb6853d697f3cb80bfc8289c2bdfa39098b662938143bc6b287f4c7cb84
SIZE (kde-amarok-v2.9.70-0aa6ae0c77_GH0.tar.gz) = 21070462

View File

@ -0,0 +1,11 @@
--- CMakeLists.txt.orig 2019-04-30 03:42:56 UTC
+++ CMakeLists.txt
@@ -207,6 +207,8 @@ if( WITH_PLAYER )
# zlib is required for mysql embedded
find_package(ZLIB REQUIRED)
set_package_properties( ZLIB PROPERTIES DESCRIPTION "zlib" TYPE REQUIRED )
+ # SSL is required for mysql embedded
+ find_package(OpenSSL REQUIRED)
# We tell users that we need 1.0.3, but we really check just >= 1.0.0. This is because
# upstream forgot to update version in lastfm/global.h, so it looks like 1.0.2. :-(

View File

@ -1,6 +1,6 @@
--- cmake/modules/FindMySQL.cmake.orig 2019-06-14 07:24:31 UTC
--- cmake/modules/FindMySQL.cmake.orig 2019-04-30 03:42:56 UTC
+++ cmake/modules/FindMySQL.cmake
@@ -31,21 +31,7 @@ if(MYSQLCONFIG_EXECUTABLE)
@@ -31,18 +31,20 @@ if(MYSQLCONFIG_EXECUTABLE)
OUTPUT_STRIP_TRAILING_WHITESPACE
)
@ -11,15 +11,41 @@
- OUTPUT_STRIP_TRAILING_WHITESPACE
- )
-
- if(NOT MC_MYSQL_EMBEDDED_LIBRARIES)
- # At least on OpenSUSE --libmysql-libs doesn't exist, so we just use
- # MYSQL_LIBRARIES for that. We'll see if that's enough when testing
- # below.
if(NOT MC_MYSQL_EMBEDDED_LIBRARIES)
# At least on OpenSUSE --libmysql-libs doesn't exist, so we just use
# MYSQL_LIBRARIES for that. We'll see if that's enough when testing
# below.
- set(MYSQL_EMBEDDED_LIBRARIES ${MYSQL_LIBRARIES})
- else()
- set(MYSQL_EMBEDDED_LIBRARIES ${MC_MYSQL_EMBEDDED_LIBRARIES})
- endif()
+ set(MYSQL_EMBEDDED_LIBRARIES "-L/usr/local/lib/mysql" -lmysqld -llz4)
endif()
+ # mysql-config removed --libmysql-libs, but amarok need libmysqld other
+ # than libmysqlclient to run mysql embedded server.
+ find_library(MYSQL_EMBEDDED_LIBRARIES NAMES mysqld libmysqld
+ PATHS
+ $ENV{MYSQL_DIR}/libmysql_r/.libs
+ $ENV{MYSQL_DIR}/lib
+ $ENV{MYSQL_DIR}/lib/mysql
+ PATH_SUFFIXES
+ mysql
+ )
else()
set(MYSQL_EMBEDDED_LIBRARIES ${MC_MYSQL_EMBEDDED_LIBRARIES})
endif()
@@ -51,7 +53,7 @@ endif()
# Try searching manually via find_path/find_library, possibly with hints
# from pkg-config
find_package(PkgConfig)
-pkg_check_modules(PC_MYSQL QUIET mysql mariadb)
+pkg_check_modules(PC_MYSQL QUIET mysql mariadb perconaserverclient)
find_path(MYSQL_INCLUDE_DIR mysql.h
PATHS
@@ -101,6 +103,10 @@ if(MYSQL_EMBEDDED_LIBRARIES)
# string(STRIP ${_mysql_libs} _mysql_libs)
# set(MYSQL_EMBEDDED_LIBRARIES ${_mysql_libs})
#endif()
+
+ string(CONCAT MC_MYSQL_LIBRARIES ${MYSQL_LIBRARIES} " -llz4")
+ string(STRIP ${MC_MYSQL_LIBRARIES} MC_MYSQL_LIBRARIES)
+ set(MYSQL_LIBRARIES ${MC_MYSQL_LIBRARIES})
cmake_push_check_state()
set(CMAKE_REQUIRED_INCLUDES ${MYSQL_INCLUDE_DIR})
set(CMAKE_REQUIRED_LIBRARIES ${MYSQL_EMBEDDED_LIBRARIES})

View File

@ -0,0 +1,11 @@
--- src/core-impl/storage/sql/mysqlestorage/CMakeLists.txt.orig 2019-04-30 03:42:56 UTC
+++ src/core-impl/storage/sql/mysqlestorage/CMakeLists.txt
@@ -25,6 +25,8 @@ target_link_libraries(amarok_storage-mysqlestorage
${MYSQL_EMBEDDED_LIBRARIES}
${CMAKE_DL_LIBS}
${ZLIB_LIBRARIES}
+ ${OPENSSL_SSL_LIBRARY}
+ ${OPENSSL_CRYPTO_LIBRARY}
)
if(${CMAKE_HOST_SYSTEM_NAME} MATCHES "FreeBSD")

View File

@ -0,0 +1,11 @@
--- src/core-impl/storage/sql/mysqlserverstorage/CMakeLists.txt.orig 2019-04-30 03:42:56 UTC
+++ src/core-impl/storage/sql/mysqlserverstorage/CMakeLists.txt
@@ -25,6 +25,8 @@ target_link_libraries(amarok_storage-mysqlserverstorag
${MYSQL_LIBRARIES}
${CMAKE_DL_LIBS}
${ZLIB_LIBRARIES}
+ ${OPENSSL_SSL_LIBRARY}
+ ${OPENSSL_CRYPTO_LIBRARY}
)
if(NOT WIN32 AND NOT APPLE)

View File

@ -4,7 +4,7 @@
PORTNAME= clementine
DISTVERSION= 1.3.1-661
DISTVERSIONSUFFIX= -g4ff370ce1
PORTREVISION= 5
PORTREVISION= 6
CATEGORIES= audio
PKGNAMESUFFIX= -player

View File

@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= elisa
PORTVERSION= 0.4.1
PORTVERSION= 0.4.2
CATEGORIES= audio kde
MASTER_SITES= KDE/stable/${PORTNAME}/${PORTVERSION}

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1561715763
SHA256 (elisa-0.4.1.tar.xz) = 77836c406d32d52245987e7d26399b006e2d333fb3d00beaea059ea69f60a057
SIZE (elisa-0.4.1.tar.xz) = 1273516
TIMESTAMP = 1561976709
SHA256 (elisa-0.4.2.tar.xz) = fc2496cad8b52daafa2c28fd033d8bd47e842de3ef3865cf0bffdd84a8712a6d
SIZE (elisa-0.4.2.tar.xz) = 1274720

View File

@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= gsequencer
DISTVERSION= 2.2.7
DISTVERSION= 2.2.10
CATEGORIES= audio
MASTER_SITES= SAVANNAH/gsequencer/${DISTVERSION:R}.x

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1561883726
SHA256 (gsequencer-2.2.7.tar.gz) = a8b544ac5e2c95f6347dd15e33e4039cc9c27e80d2b6ec1bc877f9857ddb0724
SIZE (gsequencer-2.2.7.tar.gz) = 5212743
TIMESTAMP = 1562307942
SHA256 (gsequencer-2.2.10.tar.gz) = 27633e2e2f53581bed68aa66fb812356c2af3900771b1a07d2f010aeaef7f238
SIZE (gsequencer-2.2.10.tar.gz) = 5219083

View File

@ -7,7 +7,7 @@ PORTREVISION= 3
CATEGORIES= audio
MASTER_SITES= SF
MAINTAINER= koalative@gmail.com
MAINTAINER= ports@FreeBSD.org
COMMENT= Lightweight Open Sound Control implementation
LICENSE= LGPL21

View File

@ -18,7 +18,7 @@ RUN_DEPENDS= ${PYTHON_PKGNAMEPREFIX}lxml>0:devel/py-lxml@${PY_FLAVOR} \
${PYTHON_PKGNAMEPREFIX}pygments>0:textproc/py-pygments@${PY_FLAVOR} \
${PYTHON_PKGNAMEPREFIX}rdflib>0:textproc/py-rdflib@${PY_FLAVOR}
USES= python:-3.6 shebangfix tar:bzip2 waf
USES= python shebangfix tar:bzip2 waf
SHEBANG_FILES= lv2specgen/lv2specgen.py

View File

@ -4,6 +4,7 @@
PORTNAME= mixxx
DISTVERSIONPREFIX= release-
DISTVERSION= 2.2.1
PORTREVISION= 1
CATEGORIES= audio
MAINTAINER= acm@FreeBSD.org

View File

@ -4,6 +4,7 @@
PORTNAME= mixxx
DISTVERSIONPREFIX= release-
DISTVERSION= 2.1.8
PORTREVISION= 1
CATEGORIES= audio
PKGNAMESUFFIX= 21

View File

@ -3,7 +3,7 @@
PORTNAME= mumble
DISTVERSION= 1.3.0-rc1
PORTREVISION= 4
PORTREVISION= 5
CATEGORIES= audio
MAINTAINER= feld@FreeBSD.org

View File

@ -3,7 +3,7 @@
PORTNAME= murmur
DISTVERSION= 1.3.0-rc1
PORTREVISION= 4
PORTREVISION= 5
CATEGORIES= audio net
MAINTAINER= feld@FreeBSD.org

View File

@ -3,7 +3,7 @@
PORTNAME= rhythmbox
PORTVERSION= 3.4.2
PORTREVISION= 5
PORTREVISION= 6
CATEGORIES= audio gnome
MASTER_SITES= GNOME
DIST_SUBDIR= gnome3
@ -17,9 +17,7 @@ LICENSE_FILE= ${WRKSRC}/COPYING
BUILD_DEPENDS= ${LOCALBASE}/include/linux/videodev2.h:multimedia/v4l_compat \
valac:lang/vala \
gtkdoc-check:textproc/gtk-doc \
itstool:textproc/itstool \
tdb1>0:databases/tdb1
RUN_DEPENDS= tdb1>0:databases/tdb1
itstool:textproc/itstool
LIB_DEPENDS= libmusicbrainz5.so:audio/libmusicbrainz5 \
libtotem-plparser.so:multimedia/totem-pl-parser \
libdbus-1.so:devel/dbus \
@ -30,7 +28,8 @@ LIB_DEPENDS= libmusicbrainz5.so:audio/libmusicbrainz5 \
libpeas-1.0.so:devel/libpeas \
libjson-glib-1.0.so:devel/json-glib \
libsoup-gnome-2.4.so:devel/libsoup-gnome \
libsecret-1.so:security/libsecret
libsecret-1.so:security/libsecret \
libtdb.so:databases/tdb
USES= desktop-file-utils gmake gnome libtool localbase \
pathfix pkgconfig tar:xz

View File

@ -2,6 +2,7 @@
PORTNAME= spotifyd
DISTVERSION= 0.2.9
PORTREVISION= 1
CATEGORIES= audio
MAINTAINER= tobik@FreeBSD.org

View File

@ -1,13 +1,12 @@
# $FreeBSD$
PORTNAME= supercollider
DISTVERSION= 3.9.3
PORTREVISION= 7
DISTVERSION= 3.10.2
CATEGORIES= audio
MASTER_SITES= https://github.com/supercollider/supercollider/releases/download/Version-${PORTVERSION}/
DISTNAME= SuperCollider-${PORTVERSION}-Source-linux
MAINTAINER= brittlehaus@gmail.com
MAINTAINER= ports@nicandneal.net
COMMENT= Programming language for real time audio synthesis
LICENSE= GPLv3
@ -24,7 +23,7 @@ USES= cmake compiler:c++11-lang iconv localbase pkgconfig \
qt:5 readline shared-mime-info tar:bzip2
USE_QT= buildtools_build concurrent core declarative gui linguisttools location \
network opengl printsupport qmake_build sensors \
sql webkit widgets
sql widgets webengine websockets webchannel svg
USE_XORG= x11
USE_LDCONFIG= yes
@ -54,6 +53,14 @@ SUPERNOVA_CMAKE_BOOL= SUPERNOVA
CMAKE_ARGS+= -DSSE:BOOL=FALSE -DSSE2:BOOL=FALSE
.endif
.if ${OPSYS} == FreeBSD
.if (${OSVERSION} >= 1102507 && ${OSVERSION} < 1200000) || \
(${OSVERSION} >= 1200506 && ${OSVERSION} < 1300000) || \
${OSVERSION} >= 1300014
BROKEN= fails to compile with Clang 8 due shipped Boost 1.66 libraries. Not compatible with Boost 1.70+, either
.endif
.endif
post-patch:
@${REINPLACE_CMD} -e 's|MATCHES "Linux" AND|MATCHES "FreeBSD" AND|' \
${WRKSRC}/CMakeLists.txt

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1529769258
SHA256 (SuperCollider-3.9.3-Source-linux.tar.bz2) = b939964a93709d747711552d116fb935508d39ba3fb64e55a45b0210a8eb11b5
SIZE (SuperCollider-3.9.3-Source-linux.tar.bz2) = 11060240
TIMESTAMP = 1558424872
SHA256 (SuperCollider-3.10.2-Source-linux.tar.bz2) = 389a9b3ecad7907c31f97566a48a8b2c5c53b73a8ad8004f81a5e9cb9a0fdf7a
SIZE (SuperCollider-3.10.2-Source-linux.tar.bz2) = 11366481

View File

@ -0,0 +1,14 @@
--- external_libraries/CMakeLists.txt.orig 2019-05-24 16:22:36.227027000 +0000
+++ external_libraries/CMakeLists.txt 2019-05-24 16:23:37.721453000 +0000
@@ -52,8 +52,10 @@
endif()
- if(CMAKE_SYSTEM_NAME MATCHES "Linux")
+ if(CMAKE_SYSTEM_NAME MATCHES "FreeBSD")
target_compile_options(boost_thread PRIVATE -fPIC)
+ target_compile_options(boost_system PRIVATE -fPIC)
+ target_compile_options(boost_filesystem PRIVATE -fPIC)
target_link_libraries(boost_thread rt)
endif()

View File

@ -12,4 +12,4 @@ License in 2002 when he joined the Apple Core Audio team. It is now
maintained and developed by an active and enthusiastic community. It
is used by musicians, scientists, and artists working with sound.
WWW: http://supercollider.github.io/
WWW: https://supercollider.github.io

View File

@ -227,6 +227,7 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/Classes/Crackle.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/CuspL.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/CuspN.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/CustomViewAction.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/DC.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Date.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Dbrown.schelp
@ -512,10 +513,13 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/Classes/MIDIdef.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Magnitude.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Main.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/MainMenu.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/MantissaMask.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/MaxLocalBufs.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Maybe.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Median.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Menu.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/MenuAction.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Message.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Method.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/MidEQ.schelp
@ -788,6 +792,7 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/Classes/Pxrand.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/QPalette.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/QPenPrinter.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/QtGUI.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/QuadC.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/QuadL.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/QuadN.schelp
@ -891,7 +896,6 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/Classes/SpecCentroid.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/SpecFlatness.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/SpecPcile.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Speech.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Splay.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/SplayAz.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/SplayZ.schelp
@ -950,6 +954,7 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/Classes/Thunk.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Timer.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/ToggleFF.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/ToolBar.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/TouchResponder.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/TreeView.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/TreeViewItem.schelp
@ -987,7 +992,6 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/Classes/Wavetable.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/WebView.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/WhiteNoise.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/WiiMote.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Window.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/Wrap.schelp
%%HELP%%share/SuperCollider/HelpSource/Classes/WrapIndex.schelp
@ -1020,6 +1024,7 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/Guides/More-On-Getting-Help.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/MultiClient_Setups.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/Multichannel-Expansion.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/News-3_10.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/News-3_5.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/News-3_6.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/News-3_7.schelp
@ -1039,6 +1044,7 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/Guides/SuperColliderAU.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/Sync-Async.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/SynthDefsVsSynths.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/Tour-of-Special-Functions.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/Tour_of_UGens.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/Tracing-Processes.schelp
%%HELP%%share/SuperCollider/HelpSource/Guides/UGens-and-Synths.schelp
@ -1233,6 +1239,7 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Mark_Polishook_tutorial/Japanese_version/13.schelp
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Mark_Polishook_tutorial/Japanese_version/14.schelp
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Mark_Polishook_tutorial/Japanese_version/15.schelp
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Server_Tutorial.schelp
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Streams-Patterns-Events1.schelp
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Streams-Patterns-Events2.schelp
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Streams-Patterns-Events3.schelp
@ -1240,9 +1247,11 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Streams-Patterns-Events5.schelp
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Streams-Patterns-Events6.schelp
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Streams-Patterns-Events7.schelp
%%HELP%%share/SuperCollider/HelpSource/Tutorials/Tutorial.schelp
%%HELP%%share/SuperCollider/HelpSource/browse.css
%%HELP%%share/SuperCollider/HelpSource/browse.js
%%HELP%%share/SuperCollider/HelpSource/codemirror.css
%%HELP%%share/SuperCollider/HelpSource/editor.css
%%HELP%%share/SuperCollider/HelpSource/editor.js
%%HELP%%share/SuperCollider/HelpSource/images/SC_icon.png
%%HELP%%share/SuperCollider/HelpSource/images/Swamp.png
%%HELP%%share/SuperCollider/HelpSource/images/duck_alpha.png
@ -1254,12 +1263,12 @@ share/SuperCollider/HID_Support/hut/hut_8_ledpage.yaml
%%HELP%%share/SuperCollider/HelpSource/images/plugin.svg
%%HELP%%share/SuperCollider/HelpSource/images/vduck2.jpg
%%HELP%%share/SuperCollider/HelpSource/images/vline.png
%%HELP%%share/SuperCollider/HelpSource/lang-sc.js
%%HELP%%share/SuperCollider/HelpSource/prettify.js
%%HELP%%share/SuperCollider/HelpSource/lib/codemirror-5.39.2.min.js
%%HELP%%share/SuperCollider/HelpSource/lib/codemirror-addon-simple-5.39.2.min.js
%%HELP%%share/SuperCollider/HelpSource/lib/jquery.min.js
%%HELP%%share/SuperCollider/HelpSource/scdoc.css
%%HELP%%share/SuperCollider/HelpSource/scdoc.js
%%HELP%%share/SuperCollider/HelpSource/search.js
%%HELP%%share/SuperCollider/HelpSource/syntax_colors.html
share/SuperCollider/README.md
share/SuperCollider/README_LINUX.md
share/SuperCollider/SCClassLibrary/Common/Audio/BEQSuite.sc
@ -1416,6 +1425,8 @@ share/SuperCollider/SCClassLibrary/Common/GUI/Base/EZgui.sc
share/SuperCollider/SCClassLibrary/Common/GUI/Base/FlowLayout.sc
share/SuperCollider/SCClassLibrary/Common/GUI/Base/Gradient.sc
share/SuperCollider/SCClassLibrary/Common/GUI/Base/Grid.sc
share/SuperCollider/SCClassLibrary/Common/GUI/Base/Menu.sc
share/SuperCollider/SCClassLibrary/Common/GUI/Base/QCallback.sc
share/SuperCollider/SCClassLibrary/Common/GUI/Base/QDialog.sc
share/SuperCollider/SCClassLibrary/Common/GUI/Base/QEnvelopeView.sc
share/SuperCollider/SCClassLibrary/Common/GUI/Base/QFont.sc
@ -1571,24 +1582,18 @@ share/SuperCollider/SCClassLibrary/SCDoc/SCDoc.sc
share/SuperCollider/SCClassLibrary/SCDoc/SCDocRenderer.sc
share/SuperCollider/SCClassLibrary/SCDoc/TODO
share/SuperCollider/SCClassLibrary/backwards_compatibility/PMOsc.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/AudioIn.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/Donce.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/HistoryGui.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/InterplEnv.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/JITLib.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/TDuty_old.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/WII.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/Watcher.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/WiiMoteGUI.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/deprecated-3.9.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/osc/OSCpathResponder.sc
share/SuperCollider/SCClassLibrary/deprecated/3.9/osc/OSCresponder.sc
share/SuperCollider/SCClassLibrary/deprecated/3.10/AudioIn.sc
share/SuperCollider/SCClassLibrary/deprecated/3.10/File.sc
share/SuperCollider/SCClassLibrary/deprecated/3.10/GUI/File.sc
share/SuperCollider/SCClassLibrary/deprecated/3.10/GUI/QWebView.sc
share/SuperCollider/SCClassLibrary/deprecated/3.10/deprecated-3.10.sc
share/SuperCollider/SCClassLibrary/deprecated/3.10/osc/OSCpathResponder.sc
share/SuperCollider/SCClassLibrary/deprecated/3.10/osc/OSCresponder.sc
share/SuperCollider/SCClassLibrary/scide_scqt/ScIDE.sc
share/SuperCollider/examples/GUI examples/ColorBrowser.scd
share/SuperCollider/examples/GUI examples/GUI_examples1.scd
share/SuperCollider/examples/GUI examples/GUI_examples2.scd
share/SuperCollider/examples/GUI examples/Nick's LetterGimmick.scd
share/SuperCollider/examples/GUI examples/ScopeExample.scd
share/SuperCollider/examples/GUI examples/TwoMultiSlidersInOne.scd
share/SuperCollider/examples/GUI examples/analog-drum-tuner.scd
share/SuperCollider/examples/GUI examples/rotary hommage duchamp.scd
@ -1602,6 +1607,7 @@ share/SuperCollider/examples/demonstrations/DemandingStudies.scd
share/SuperCollider/examples/demonstrations/DrumSynths.scd
share/SuperCollider/examples/demonstrations/GetTheTwits.scd
share/SuperCollider/examples/demonstrations/HarmonicsVoice.html
share/SuperCollider/examples/demonstrations/HarmonicsVoice.scd
share/SuperCollider/examples/demonstrations/Modal Space.scd
share/SuperCollider/examples/demonstrations/SC2-examples_1.scd
share/SuperCollider/examples/demonstrations/SC2-examples_2.scd
@ -1614,7 +1620,7 @@ share/SuperCollider/examples/demonstrations/env automation.scd
share/SuperCollider/examples/demonstrations/fft.scd
share/SuperCollider/examples/demonstrations/more graphs.scd
share/SuperCollider/examples/demonstrations/oh yes more fibs.scd
share/SuperCollider/examples/demonstrations/sc_onliner.scd
share/SuperCollider/examples/demonstrations/sc_oneliner.scd
share/SuperCollider/examples/demonstrations/single_sample_feedback.scd
share/SuperCollider/examples/demonstrations/single_sample_feedback_02.scd
share/SuperCollider/examples/demonstrations/snare909.scd
@ -1622,6 +1628,7 @@ share/SuperCollider/examples/demonstrations/stealthissound.scd
share/SuperCollider/examples/other/Exploring_SCLang.scd
share/SuperCollider/examples/other/KeyboardWindow.scd
share/SuperCollider/examples/other/keepyuppy.scd
share/SuperCollider/examples/other/onetwoonetwo.sc
share/SuperCollider/examples/other/quines.scd
share/SuperCollider/examples/pieces/DreamHouse.scd
share/SuperCollider/examples/pieces/DrummerSynthDef.scd
@ -1658,7 +1665,6 @@ share/SuperCollider/translations/scide_ru.qm
share/SuperCollider/translations/scide_sl.qm
share/SuperCollider/translations/scide_sv.qm
share/SuperCollider/translations/scide_zh.qm
share/doc/SuperCollider/examples/onetwoonetwo.sc
share/mime/packages/supercollider.xml
share/pixmaps/sc_ide.svg
share/pixmaps/supercollider.png

View File

@ -2,7 +2,7 @@
# $FreeBSD$
PORTNAME= virtual_oss
PORTVERSION= 1.2.2
PORTVERSION= 1.2.4
CATEGORIES= audio
MASTER_SITES= http://www.selasky.org/hans_petter/distfiles/ \
http://home.selasky.org/distfiles/
@ -31,7 +31,7 @@ BLUETOOTH_MAKE_ARGS= HAVE_BLUETOOTH="YES"
BT_SPEAKER_DESC= Build with bluetooth speaker utility
BT_SPEAKER_PLIST_FILES= sbin/virtual_bt_speaker \
man/man8/virtual_bt_speaker.8.gz
man/man8/virtual_bt_speaker.8.gz
BT_SPEAKER_MAKE_ARGS= HAVE_BLUETOOTH_SPEAKER="YES"
DEBUG_MAKE_ARGS= HAVE_DEBUG="YES"

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1553974911
SHA256 (virtual_oss-1.2.2.tar.bz2) = f92302f13a02ac4dbb2e5ee14f8382157179a90459f67e1607225fc9b7cf183c
SIZE (virtual_oss-1.2.2.tar.bz2) = 45860
TIMESTAMP = 1562317772
SHA256 (virtual_oss-1.2.4.tar.bz2) = 413376691598652867259faddd1aedc0fccd2e09fb14c64fd49ecc1ac6525de3
SIZE (virtual_oss-1.2.4.tar.bz2) = 46001

View File

@ -37,12 +37,8 @@ post-extract:
post-patch:
@${REINPLACE_CMD} -e 's|#!/bin/bash|#!/bin/sh|' ${WRKSRC}/dpf/utils/generate-ttl.sh
.if ${ARCH} == aarch64 || ${ARCH:Marmv*} || ${ARCH:Mmips*} || ${ARCH:Mpowerpc*} || ${ARCH} == sparc64
${REINPLACE_CMD} -e '/-mfpmath=sse/d' \
-e 's/-mtune=generic -msse -msse2//' \
${WRKSRC}/Makefile.mk ${WRKSRC}/Makefile.mk
${REINPLACE_CMD} -e '/-mfpmath=sse/d' \
-e 's/-mtune=generic -msse -msse2//' \
${WRKSRC}/Makefile.mk ${WRKSRC}/dpf/dgl/Makefile.mk
${REINPLACE_CMD} -e 's/-mtune=generic -msse -msse2//' \
${WRKSRC}/dpf/Makefile.base.mk
.endif
.include <bsd.port.post.mk>

View File

@ -3,7 +3,7 @@
PORTNAME= hyperfine
DISTVERSIONPREFIX= v
DISTVERSION= 1.6.0
PORTREVISION= 0
PORTREVISION= 1
CATEGORIES= benchmarks
MAINTAINER= pizzamig@FreeBSD.org

View File

@ -14,7 +14,7 @@ DIST_SUBDIR= ${PORTNAME}
EXTRACT_ONLY= BrickUtils-${DISTVERSION}${EXTRACT_SUFX} \
${PORTNAME}_icons${EXTRACT_SUFX}
MAINTAINER= koalative@gmail.com
MAINTAINER= ports@FreeBSD.org
COMMENT= Utility for building models with LEGO
LICENSE= GPLv3

View File

@ -2,56 +2,34 @@
# $FreeBSD$
PORTNAME= ldraw
PORTVERSION= 201501
DISTVERSION= 20181208
PORTEPOCH= 1
CATEGORIES= cad
MASTER_SITES= http://www.ldraw.org/library/updates/
DISTNAME= complete
DIST_SUBDIR= ldraw/${PORTVERSION}
MASTER_SITES= https://www.ldraw.org/library/updates/:parts \
https://www.ldraw.org/library/official/:config
DISTFILES= complete.zip:parts LDConfig.ldr:config
DIST_SUBDIR= ${DISTNAME}-${DISTVERSION}
EXTRACT_ONLY= complete.zip
MAINTAINER= koalative@gmail.com
COMMENT= LDraw parts library
MAINTAINER= ports@FreeBSD.org
COMMENT= LDraw-format CAD files representing many of LEGO bricks produced
LICENSE= CDDL CC-BY-NC-SA-2.0
LICENSE_COMB= dual
LICENSE_FILE_CC-BY-NC-SA-2.0= ${WRKSRC}/CAlicense.txt
LICENSE= CC-BY-2.0
WRKSRC= ${WRKDIR}/${PORTNAME}
USES= zip
USES= dos2unix gmake zip:infozip
DOS2UNIX_GLOB= *.h makefile mklist.c *.txt *.dat
PORTDATA= *
PORTDOCS= Readme.txt
OPTIONS_DEFINE= DOCS
SUB_FILES= pkg-message
BUILD_WRKSRC= ${WRKSRC}/mklist
MAKEFILE= makefile
post-extract-script:
@(cd ${WRKSRC} && ${UNZIP_CMD} -qo -d \
${WRKSRC}/mklist ${WRKSRC}/mklist1_6.zip)
@(cd ${WRKSRC}/mklist/include && ${MV} * ..)
post-patch:
@${REINPLACE_CMD} -e 's|CC=gcc|CC?=gcc|' \
-e 's|CFLAGS=|CFLAGS?=|' \
${WRKSRC}/mklist/makefile
@${REINPLACE_CMD} -e 's|PARTS|parts|' \
${WRKSRC}/mklist/mklist.c
NO_BUILD= yes
NO_ARCH= yes
do-install:
.for f in models p parts LDCfgalt.ldr LDConfig.ldr LDConfig_TLG.ldr
@(cd ${WRKSRC} ; ${COPYTREE_SHARE} ${f} ${STAGEDIR}${DATADIR})
.endfor
@${MKDIR} ${STAGEDIR}${PREFIX}/share/ldraw
cd ${WRKDIR}/ldraw && \
${COPYTREE_SHARE} p ${STAGEDIR}${PREFIX}/share/ldraw && \
${COPYTREE_SHARE} parts ${STAGEDIR}${PREFIX}/share/ldraw
${INSTALL_DATA} ${DISTDIR}/${DIST_SUBDIR}/LDConfig.ldr ${STAGEDIR}${PREFIX}/share/ldraw
${INSTALL_PROGRAM} ${WRKSRC}/mklist/mklist ${STAGEDIR}${DATADIR}
@(cd ${STAGEDIR}${DATADIR} && ./mklist -d)
do-install-DOCS-on:
@${MKDIR} ${STAGEDIR}${DOCSDIR}
${INSTALL_DATA} ${PORTDOCS:S|^|${WRKSRC}/|} ${STAGEDIR}${DOCSDIR}
post-install: # autoplist: ~16k files all under share/ldraw
@cd ${STAGEDIR}${PREFIX} && \
${FIND} * -type f >> ${TMPPLIST}
.include <bsd.port.mk>

View File

@ -1,2 +1,5 @@
SHA256 (ldraw/201501/complete.zip) = ca4cf9c46f7fc73d0d1a55ca8270635cfe93ab2244c88640457090887e07ed7a
SIZE (ldraw/201501/complete.zip) = 29881376
TIMESTAMP = 1558146584
SHA256 (ldraw-20181208-20181208/complete.zip) = 9cef56049350b67c1d625033833a617146d0f42f4be08f34f4c51e59eca84afc
SIZE (ldraw-20181208-20181208/complete.zip) = 41548599
SHA256 (ldraw-20181208-20181208/LDConfig.ldr) = 23a3a675b11f427afc0031df18949528dccfd92a7c2e652ced33e130eb81a1d7
SIZE (ldraw-20181208-20181208/LDConfig.ldr) = 29466

View File

@ -1,22 +0,0 @@
--- ./mklist/mklist.c.orig 2013-11-15 20:23:32.000000000 +0100
+++ ./mklist/mklist.c 2013-11-15 20:25:12.000000000 +0100
@@ -53,8 +53,8 @@
/*****************************************************************/
/* Filename length compatibility stuff */
/*****************************************************************/
-#ifndef _MAX_PATH
-#define _MAX_PATH 256
+#ifndef MAX_PATH
+#define MAX_PATH 256
#endif
char shortfilepath[MAX_PATH];
char shortfilename[MAX_PATH];
@@ -84,7 +84,7 @@
int GetShortPathName(char *longpath, char * shortpath, int psize)
{
strncpy(shortpath, longpath, psize);
- return(strlen(shortpath);
+ return(strlen(shortpath));
}
#endif

View File

@ -1,11 +0,0 @@
===============================================================================
LDraw has been installed.
You can make parts.lst with
%%DATADIR%%/mklist -h
Default is sorted by Description parts.lst (mklist -d). You can change this.
===============================================================================

View File

@ -1,8 +1,8 @@
LDraw is an open standard for LEGO CAD programs that allow the user to create
LDraw-TM is an open standard for LEGO CAD programs that allow the user to create
virtual LEGO models and scenes. You can use it to document models you have
physically built, create building instructions just like LEGO, render 3D photo
realistic images of your virtual models and even make animations.
The possibilities are endless. Unlike real LEGO bricks where you are limited by
the number of parts and colors, in LDraw nothing is impossible.
realistic images of your virtual models and even make animations. The
possibilities are endless. Unlike real LEGO bricks where you are limited by the
number of parts and colors, in LDraw nothing is impossible.
WWW: http://www.ldraw.org/
WWW: https://www.ldraw.org/

View File

@ -2,7 +2,7 @@
PORTNAME= lepton-eda
PORTVERSION= 1.9.7
PORTREVISION= 1
PORTREVISION= 2
DISTVERSIONSUFFIX= -20181211
CATEGORIES= cad
@ -18,9 +18,9 @@ LIB_DEPENDS= libfontconfig.so:x11-fonts/fontconfig \
libpng.so:graphics/png \
libstroke.so:devel/libstroke
USES= autoreconf desktop-file-utils gettext-tools gnome groff:build \
libtool localbase makeinfo pathfix perl5 pkgconfig python:run \
shared-mime-info shebangfix
USES= autoreconf desktop-file-utils gettext-tools gnome \
groff:build libtool localbase makeinfo pathfix perl5 \
pkgconfig python:2.7,run shared-mime-info shebangfix
USE_GITHUB= yes
USE_GNOME= cairo gtk20
USE_LDCONFIG= yes
@ -53,10 +53,6 @@ OPTIONS_SUB= yes
NLS_CONFIGURE_ENABLE= nls
NLS_USES= gettext-runtime
post-patch:
@${REINPLACE_CMD} -e 's,guile-2\.0,guile-2.2,' \
${WRKSRC}/m4/geda-guile.m4
# work around for errors while running
# build-tools/icon-theme-installer:
#

View File

@ -0,0 +1,26 @@
--- m4/geda-guile.m4.orig 2018-12-11 19:24:41 UTC
+++ m4/geda-guile.m4
@@ -34,9 +34,20 @@ AC_DEFUN([AX_CHECK_GUILE],
GUILE_MIN_MINOR=`echo ${GUILE_MIN_VER} | sed -e 's;[[^\.]]*\.;;' -e 's;\..*;;g'`
GUILE_MIN_TEENY=`echo ${GUILE_MIN_VER} | sed -e 's;.*\.;;'`
- PKG_CHECK_MODULES(GUILE, [guile-2.0 >= $GUILE_MIN_VER],
- [GUILE_PKG_NAME=guile-2.0],
- [AC_MSG_ERROR([you need at least version ${GUILE_MIN_VER} of guile])])
+ _found_pkg_config_guile=yes
+ PKG_CHECK_MODULES(GUILE, [guile-2.2 >= $GUILE_MIN_VER],
+ [GUILE_PKG_NAME=guile-2.2], [_found_pkg_config_guile=no])
+
+ if test "${_found_pkg_config_guile}" = "no" ; then
+ PKG_CHECK_MODULES(GUILE, [guile-2.0 >= $GUILE_MIN_VER],
+ [_found_pkg_config_guile=yes
+ GUILE_PKG_NAME=guile-2.0],
+ [_found_pkg_config_guile=no])
+ fi
+
+ if test "${_found_pkg_config_guile}" = "no" ; then
+ AC_MSG_ERROR([you need at least version ${GUILE_MIN_VER} of guile])
+ fi
AC_SUBST([GUILE_PKG_NAME])

View File

@ -0,0 +1,102 @@
--- Makefile.orig 2006-09-03 18:00:00 UTC
+++ Makefile
@@ -1,15 +1,15 @@
-CFLAGS = -Wall -W -O2
-LDFLAGS = -s
+CFLAGS ?= -Wall -W -O2
+LDFLAGS ?= -s
-CC = gcc
-INSTALL = install
-INSTALL_DATA = $(INSTALL) -m 444
-INSTALL_PROGRAM = $(INSTALL) -m 555
+CC ?= gcc
+INSTALL ?= install
+INSTALL_DATA ?= $(INSTALL) -m 444
+INSTALL_PROGRAM ?= $(INSTALL) -m 555
-prefix = /usr/local
+prefix = ${PREFIX}
exec_prefix = $(prefix)
bindir = $(exec_prefix)/bin
-mandir = $(prefix)/share/man
+mandir = $(prefix)/man
man1dir = $(mandir)/man1
manext = .1
@@ -23,7 +23,7 @@ all: $(BIN)
$(CC) $(CFLAGS) -c $<
base91: cli.o base91.o
- $(CC) $(LDFLAGS) -o $@ $^
+ $(CC) $(LDFLAGS) -o $@ cli.o base91.o
install: all
mkdir -p $(DESTDIR)$(bindir)

View File

@ -0,0 +1,11 @@
basE91 is an advanced method for encoding binary data as ASCII characters.
It is similar to UUencode or base64, but is more efficient.
The overhead produced by basE91 depends on the input data. It amounts at most
to 23% (versus 33% for base64) and can range down to 14%, which typically
occurs on 0-byte blocks.
This makes basE91 very useful for transferring larger files over binary unsafe
connections like e-mail or terminal lines.
WWW: http://base91.sourceforge.net/

View File

@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= bencode.py
PORTVERSION= 2.0.0
PORTVERSION= 2.1.0
CATEGORIES= converters devel python
MASTER_SITES= CHEESESHOP
PKGNAMEPREFIX= ${PYTHON_PKGNAMEPREFIX}

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1514062950
SHA256 (bencode.py-2.0.0.tar.gz) = 067cf936e29a7b698d2b4d00902343b78d434d73d837c33d6ca1a8be6038fe72
SIZE (bencode.py-2.0.0.tar.gz) = 7266
TIMESTAMP = 1560762752
SHA256 (bencode.py-2.1.0.tar.gz) = 7d65b02f174097a442a2b138208aee7fe104d2ce79e7a29fb457d0e02f38fc3d
SIZE (bencode.py-2.1.0.tar.gz) = 17076

View File

@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= cego
PORTVERSION= 2.44.14
PORTVERSION= 2.45.0
CATEGORIES= databases
MASTER_SITES= http://www.lemke-it.com/

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1560945238
SHA256 (cego-2.44.14.tar.gz) = 778f6094e4f72f4afca7d44e7bb6b4360a3e1b60ef1cfd23d6eca8eca61c925e
SIZE (cego-2.44.14.tar.gz) = 3140497
TIMESTAMP = 1562162318
SHA256 (cego-2.45.0.tar.gz) = 7b8dad4815d621a0daec9b811d61a7be50aabf7998c1088620283d8c27244550
SIZE (cego-2.45.0.tar.gz) = 3148710

View File

@ -24,7 +24,9 @@ include/cego/CegoAdminHandler.h
include/cego/CegoAdminThread.h
include/cego/CegoAdminThreadPool.h
include/cego/CegoAggregation.h
include/cego/CegoAliasObject.h
include/cego/CegoAlterDesc.h
include/cego/CegoAttrAlias.h
include/cego/CegoAttrComp.h
include/cego/CegoAttrCond.h
include/cego/CegoAttrDesc.h

View File

@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= cegobridge
PORTVERSION= 1.5.0
PORTVERSION= 1.5.2
CATEGORIES= databases
MASTER_SITES= http://www.lemke-it.com/

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1555833179
SHA256 (cegobridge-1.5.0.tar.gz) = 8e21a2247bb227e5d075d6728eef3dec7c4359bcaedb1b39e1da9fa020085a24
SIZE (cegobridge-1.5.0.tar.gz) = 691265
TIMESTAMP = 1562399754
SHA256 (cegobridge-1.5.2.tar.gz) = f6f46f2dc1bb4ee2404b77f82797689c468be4eb1c13f280682a82ebb641779e
SIZE (cegobridge-1.5.2.tar.gz) = 699766

View File

@ -5,6 +5,7 @@ PORTNAME= clickhouse
PORTVERSION= 19.5.3.8
DISTVERSIONPREFIX= v
DISTVERSIONSUFFIX= -stable
PORTREVISION= 1
CATEGORIES= databases
MAINTAINER= proler@gmail.com

View File

@ -2,7 +2,7 @@
PORTNAME= mongodb
DISTVERSIONPREFIX= r
DISTVERSION= 3.6.12
DISTVERSION= 3.6.13
CATEGORIES= databases net
MASTER_SITES= https://fastdl.mongodb.org/src/ \
http://fastdl.mongodb.org/src/ \

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1555162460
SHA256 (mongodb-src-r3.6.12.tar.gz) = 74d882bee1f11adfc2e5b73d27cf87886109331e280cebcd93ce66d2226321ba
SIZE (mongodb-src-r3.6.12.tar.gz) = 40847074
TIMESTAMP = 1562087330
SHA256 (mongodb-src-r3.6.13.tar.gz) = e4f1ea19dd22446d0348dde39fd229f8cae759d75a06509be43a2f5517997bd5
SIZE (mongodb-src-r3.6.13.tar.gz) = 40853787

View File

@ -3,7 +3,7 @@
PORTNAME?= mysql
PORTVERSION= 5.7.26
PORTREVISION?= 1
PORTREVISION?= 2
CATEGORIES= databases ipv6
MASTER_SITES= MYSQL/MySQL-5.7
PKGNAMESUFFIX?= 57-server

View File

@ -0,0 +1,10 @@
--- rapid/plugin/x/ngs/include/ngs_common/protocol_protobuf.h.orig 2019-04-13 13:32:15 UTC
+++ rapid/plugin/x/ngs/include/ngs_common/protocol_protobuf.h
@@ -29,7 +29,6 @@
#include <google/protobuf/io/tokenizer.h>
#include <google/protobuf/io/zero_copy_stream.h>
#include <google/protobuf/wire_format_lite.h>
-#include <google/protobuf/wire_format_lite_inl.h>
#include <google/protobuf/dynamic_message.h>
#include "mysqlx_connection.pb.h"

View File

@ -3,7 +3,7 @@
PORTNAME?= mysql
PORTVERSION= 8.0.16
PORTREVISION?= 0
PORTREVISION?= 1
CATEGORIES= databases ipv6
MASTER_SITES= MYSQL/MySQL-8.0
PKGNAMESUFFIX?= 80-server

View File

@ -0,0 +1,10 @@
--- plugin/x/client/mysqlxclient/xmessage.h.orig 2019-04-13 11:46:31 UTC
+++ plugin/x/client/mysqlxclient/xmessage.h
@@ -36,7 +36,6 @@
#include <google/protobuf/repeated_field.h>
#include <google/protobuf/text_format.h>
#include <google/protobuf/wire_format_lite.h>
-#include <google/protobuf/wire_format_lite_inl.h>
#ifdef USE_MYSQLX_FULL_PROTO

View File

@ -0,0 +1,10 @@
--- plugin/x/ngs/include/ngs/protocol/protocol_protobuf.h.orig 2019-04-13 11:46:31 UTC
+++ plugin/x/ngs/include/ngs/protocol/protocol_protobuf.h
@@ -38,7 +38,6 @@
#include <google/protobuf/repeated_field.h>
#include <google/protobuf/text_format.h>
#include <google/protobuf/wire_format_lite.h>
-#include <google/protobuf/wire_format_lite_inl.h>
#ifdef USE_MYSQLX_FULL_PROTO
#include "plugin/x/generated/protobuf/mysqlx.pb.h"

View File

@ -2,7 +2,7 @@
# $FreeBSD$
PORTNAME= postgresql-repmgr
PORTVERSION= 4.3.0
PORTVERSION= 4.4.0
CATEGORIES= databases
MASTER_SITES= http://www.repmgr.org/download/
DISTNAME= repmgr-${PORTVERSION}

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1554377513
SHA256 (repmgr-4.3.0.tar.gz) = 424f6ed84291eac877733d3a97e5e653c9d240ef2e85dfcf9e26d6a81d383001
SIZE (repmgr-4.3.0.tar.gz) = 385506
TIMESTAMP = 1561629967
SHA256 (repmgr-4.4.0.tar.gz) = bd1cf83f0790dbb133b653d123b4c7cba33fbed2be343c95163f84d1ec5c6a11
SIZE (repmgr-4.4.0.tar.gz) = 416148

View File

@ -8,6 +8,8 @@ share/postgresql/extension/repmgr--4.1--4.2.sql
share/postgresql/extension/repmgr--4.2--4.3.sql
share/postgresql/extension/repmgr--4.2.sql
share/postgresql/extension/repmgr--4.3.sql
share/postgresql/extension/repmgr--4.3--4.4.sql
share/postgresql/extension/repmgr--4.4.sql
share/postgresql/extension/repmgr--unpackaged--4.0.sql
share/postgresql/extension/repmgr.control
@sample etc/repmgr.conf.sample

View File

@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= puppetdb-terminus
PORTVERSION= 5.2.8
PORTVERSION= 5.2.9
CATEGORIES= databases ruby
MASTER_SITES= https://downloads.puppetlabs.com/puppetdb/
PKGNAMESUFFIX= 5

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1554308533
SHA256 (puppetdb-5.2.8.tar.gz) = 5bdd6a1d491d55bdb8dcc8a2f9f7a19873f5c38bca0da1d7dcf1db61e426ad9e
SIZE (puppetdb-5.2.8.tar.gz) = 26033383
TIMESTAMP = 1561668794
SHA256 (puppetdb-5.2.9.tar.gz) = c9bb7af9635893ab4c508577794b613a19a362a7f86b0824b1ff1a6ed4982c42
SIZE (puppetdb-5.2.9.tar.gz) = 26038016

View File

@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= puppetdb-terminus
PORTVERSION= 6.3.3
PORTVERSION= 6.3.4
CATEGORIES= databases ruby
MASTER_SITES= https://downloads.puppetlabs.com/puppetdb/
PKGNAMESUFFIX= 6

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1561084247
SHA256 (puppetdb-6.3.3.tar.gz) = 8d32b420b36d391520c9f15ffaa6cebcfdd625a568b59058514cb23c1148fea0
SIZE (puppetdb-6.3.3.tar.gz) = 41714959
TIMESTAMP = 1561668800
SHA256 (puppetdb-6.3.4.tar.gz) = 2093e263bb8af860d578a84c5ee531fbb05ac3545d39b681c1d6385f44b99bb6
SIZE (puppetdb-6.3.4.tar.gz) = 41716289

View File

@ -1,8 +1,7 @@
# $FreeBSD$
PORTNAME= puppetdb
PORTVERSION= 5.2.8
PORTREVISION= 2
PORTVERSION= 5.2.9
CATEGORIES= databases java
MASTER_SITES= https://downloads.puppetlabs.com/puppetdb/
PKGNAMESUFFIX= 5

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1554308496
SHA256 (puppetdb-5.2.8.tar.gz) = 5bdd6a1d491d55bdb8dcc8a2f9f7a19873f5c38bca0da1d7dcf1db61e426ad9e
SIZE (puppetdb-5.2.8.tar.gz) = 26033383
TIMESTAMP = 1561668785
SHA256 (puppetdb-5.2.9.tar.gz) = c9bb7af9635893ab4c508577794b613a19a362a7f86b0824b1ff1a6ed4982c42
SIZE (puppetdb-5.2.9.tar.gz) = 26038016

View File

@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= puppetdb
PORTVERSION= 6.3.3
PORTVERSION= 6.3.4
CATEGORIES= databases java
MASTER_SITES= https://downloads.puppetlabs.com/puppetdb/
PKGNAMESUFFIX= 6

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1561084234
SHA256 (puppetdb-6.3.3.tar.gz) = 8d32b420b36d391520c9f15ffaa6cebcfdd625a568b59058514cb23c1148fea0
SIZE (puppetdb-6.3.3.tar.gz) = 41714959
TIMESTAMP = 1561668772
SHA256 (puppetdb-6.3.4.tar.gz) = 2093e263bb8af860d578a84c5ee531fbb05ac3545d39b681c1d6385f44b99bb6
SIZE (puppetdb-6.3.4.tar.gz) = 41716289

View File

@ -14,7 +14,7 @@ COMMENT= Access a MySQL database through Python
LICENSE= GPLv2
LICENSE_FILE= ${WRKSRC}/GPL-2.0
USES= mysql python:2.7
USES= compiler:c11 mysql python:2.7
USE_PYTHON= autoplist distutils
USE_GITHUB= yes
GH_ACCOUNT= farcepest

View File

@ -2,7 +2,7 @@
# $FreeBSD$
PORTNAME= pg8000
PORTVERSION= 1.13.1
PORTVERSION= 1.13.2
CATEGORIES= databases python
MASTER_SITES= CHEESESHOP
PKGNAMEPREFIX= ${PYTHON_PKGNAMEPREFIX}

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1550130131
SHA256 (pg8000-1.13.1.tar.gz) = 2208c7aaffe8d61f5c4ccbefeb74ba033003899e64aee37c0eb98aadae8b9c6b
SIZE (pg8000-1.13.1.tar.gz) = 57132
TIMESTAMP = 1562143981
SHA256 (pg8000-1.13.2.tar.gz) = eebcb4176a7e407987e525a07454882f611985e0becb2b73f76efb93bbdc0aab
SIZE (pg8000-1.13.2.tar.gz) = 55835

View File

@ -5,7 +5,7 @@ PORTVERSION= 0.10.9
CATEGORIES= databases rubygems
MASTER_SITES= RG
MAINTAINER= ruby@FreeBSD.org
MAINTAINER= sunpoet@FreeBSD.org
COMMENT= Conventions-based JSON generation for Rails
LICENSE= MIT

View File

@ -1,11 +1,11 @@
# $FreeBSD$
PORTNAME= activerecord-import
PORTVERSION= 0.28.2
PORTVERSION= 1.0.2
CATEGORIES= databases rubygems
MASTER_SITES= RG
MAINTAINER= ruby@FreeBSD.org
MAINTAINER= sunpoet@FreeBSD.org
COMMENT= Bulk import many records into an ActiveRecord DB
LICENSE= BSD2CLAUSE RUBY

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1561910739
SHA256 (rubygem/activerecord-import-0.28.2.gem) = 06fb937ea93ce6e9291d5a2507f5c2cb7675de9d75566a2c713c942fa156eb39
SIZE (rubygem/activerecord-import-0.28.2.gem) = 62976
TIMESTAMP = 1562427748
SHA256 (rubygem/activerecord-import-1.0.2.gem) = 2c7e1eda9b6a1b06b090e4a4a6716eda8bba521fb2a3207b18e5e67b50014881
SIZE (rubygem/activerecord-import-1.0.2.gem) = 64000

View File

@ -5,7 +5,7 @@ PORTVERSION= 1.1.0
CATEGORIES= databases rubygems
MASTER_SITES= RG
MAINTAINER= ruby@FreeBSD.org
MAINTAINER= sunpoet@FreeBSD.org
COMMENT= ORM that maps REST resources to Ruby objects
LICENSE= MIT

View File

@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= anydesk
DISTVERSION= 2.9.1
DISTVERSION= 5.1.0
CATEGORIES= deskutils
MASTER_SITES= https://download.anydesk.com/freebsd/
DISTNAME= ${PORTNAME}-freebsd-${PORTVERSION}-${ARCH:S/amd64/x86_64/:S/i386/i386/}
@ -16,11 +16,17 @@ LICENSE_PERMS= auto-accept
ONLY_FOR_ARCHS= amd64 i386
LIB_DEPENDS= libgtkglext-x11-1.0.so:x11-toolkits/gtkglext
LIB_DEPENDS= libfontconfig.so:x11-fonts/fontconfig \
libfreetype.so:print/freetype2 \
libgtkglext-x11-1.0.so:x11-toolkits/gtkglext \
libinotify.so:devel/libinotify \
libpolkit-gobject-1.so:sysutils/polkit
USE_GL= gl
USE_GNOME= gtk20 glib20 gdkpixbuf2 cairo
USE_XORG= x11 xi xcb xrandr xtst xext xfixes xdamage
USES= gl gnome
USE_GL= gl glu
USE_GNOME= cairo gdkpixbuf2 glib20 gtk20 pangox-compat
USE_XORG= x11 xcb xdamage xext xfixes xi xrandr xrender xtst
NO_BUILD= YES
WRKSRC= ${WRKDIR}/${PORTNAME}-${PORTVERSION}

View File

@ -1,5 +1,3 @@
TIMESTAMP = 1521392807
SHA256 (anydesk-freebsd-2.9.1-x86_64.tar.gz) = aacc333b063b52f3f2b3c795a88003898faf51df733aa7c540c88db68bbdba69
SIZE (anydesk-freebsd-2.9.1-x86_64.tar.gz) = 2574053
SHA256 (anydesk-freebsd-2.9.1-i386.tar.gz) = 267abec3fb76af7436ed8ab43047d4988b923a1451da3b734aab873cbb1eb0f5
SIZE (anydesk-freebsd-2.9.1-i386.tar.gz) = 2418470
TIMESTAMP = 1562435526
SHA256 (anydesk-freebsd-5.1.0-x86_64.tar.gz) = f5bf21e896f183391da64de4263ab186cdeab7ceaa9b9927dccca0a5d68f4c02
SIZE (anydesk-freebsd-5.1.0-x86_64.tar.gz) = 4280118

View File

@ -1,8 +1,6 @@
AnyDesk is fast remote desktop which uses DeskRT to provide
a considerably better image quality and responsiveness than
competing screensharing and remote desktop products.
DeskRT is a new and innovative video codec specifically
designed for the transmission of image material from
graphical user interfaces.
AnyDesk is fast remote desktop which uses DeskRT to provide a considerably
better image quality and responsiveness than competing screensharing and remote
desktop products. DeskRT is a new and innovative video codec specifically
designed for the transmission of image material from graphical user interfaces.
WWW: https://anydesk.com/remote-desktop

View File

@ -2,7 +2,7 @@
# $FreeBSD$
PORTNAME= nextcloudclient
PORTVERSION= 0.0.0.20190207
PORTVERSION= 0.0.0.20190705
PORTREVISION= 2
CATEGORIES= deskutils
@ -28,7 +28,7 @@ DEBUG= yes
USE_GITHUB= yes
GH_ACCOUNT= nextcloud
GH_PROJECT= desktop
GH_TAGNAME= ca624def40d5e431bc84a157ffba1bc187d5ecee
GH_TAGNAME= c897564d28c04029f09dcce20078e9adb3b57518
#OPTIONS_DEFINE= DEBUG DOCS
OPTIONS_DEFINE= DEBUG # DOCS doesn't build currently

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1549530153
SHA256 (nextcloud-desktop-0.0.0.20190207-ca624def40d5e431bc84a157ffba1bc187d5ecee_GH0.tar.gz) = 2945ee66c80dfa420bcd529c4764d6ed906cd0aff262467afb50e6803a0e74d9
SIZE (nextcloud-desktop-0.0.0.20190207-ca624def40d5e431bc84a157ffba1bc187d5ecee_GH0.tar.gz) = 18974468
TIMESTAMP = 1562312299
SHA256 (nextcloud-desktop-0.0.0.20190705-c897564d28c04029f09dcce20078e9adb3b57518_GH0.tar.gz) = f79a60dd379d2e53efa43263be5eedef8aef03bd140cb4c116949993be96ee5d
SIZE (nextcloud-desktop-0.0.0.20190705-c897564d28c04029f09dcce20078e9adb3b57518_GH0.tar.gz) = 19097791

View File

@ -12,10 +12,10 @@ include/nextcloudsync/mirall/syncfileitem.h
include/nextcloudsync/mirall/syncresult.h
lib/libnextcloudsync.so
lib/libnextcloudsync.so.0
lib/libnextcloudsync.so.2.5.2
lib/libnextcloudsync.so.2.5.3
lib/nextcloud/libocsync.so
lib/nextcloud/libocsync.so.0
lib/nextcloud/libocsync.so.2.5.2
lib/nextcloud/libocsync.so.2.5.3
share/applications/nextcloud.desktop
share/caja-python/extensions/syncstate-Nextcloud.py
share/icons/hicolor/1024x1024/apps/Nextcloud.png
@ -89,6 +89,7 @@ share/nextcloud/i18n/client_TW.qm
share/nextcloud/i18n/client_bg.qm
share/nextcloud/i18n/client_ca.qm
share/nextcloud/i18n/client_cs.qm
share/nextcloud/i18n/client_da.qm
share/nextcloud/i18n/client_de.qm
share/nextcloud/i18n/client_el.qm
share/nextcloud/i18n/client_en.qm
@ -111,11 +112,14 @@ share/nextcloud/i18n/client_fa.qm
share/nextcloud/i18n/client_fi.qm
share/nextcloud/i18n/client_fr.qm
share/nextcloud/i18n/client_gl.qm
share/nextcloud/i18n/client_he.qm
share/nextcloud/i18n/client_hu.qm
share/nextcloud/i18n/client_id.qm
share/nextcloud/i18n/client_is.qm
share/nextcloud/i18n/client_it.qm
share/nextcloud/i18n/client_ja.qm
share/nextcloud/i18n/client_lt_LT.qm
share/nextcloud/i18n/client_lv.qm
share/nextcloud/i18n/client_nb_NO.qm
share/nextcloud/i18n/client_nl.qm
share/nextcloud/i18n/client_pl.qm

View File

@ -7,7 +7,7 @@ PORTEPOCH= 1
CATEGORIES= deskutils
MASTER_SITES= SF/${PORTNAME}/${PORTNAME}/${PORTNAME}-${PORTVERSION}
MAINTAINER= koalative@gmail.com
MAINTAINER= ports@FreeBSD.org
COMMENT= Lightweight GTK+ clipboard manager
LICENSE= GPLv3

View File

@ -11,7 +11,7 @@ COMMENT= Simple command-line snippet manager, written in Go
LICENSE= MIT
LICENSE_FILE= ${WRKSRC}/LICENSE
USES= go
USES= go:modules
USE_GITHUB= yes
GH_ACCOUNT= knqyf263
GH_TUPLE= \

View File

@ -9,7 +9,7 @@ PKGNAMEPREFIX= ${PYTHON_PKGNAMEPREFIX}
DISTNAME= Send2Trash-${PORTVERSION}
DIST_SUBDIR= python
MAINTAINER= koalative@gmail.com
MAINTAINER= ports@FreeBSD.org
COMMENT= Small package that sends files to the Trash
LICENSE= BSD3CLAUSE

View File

@ -1,8 +1,7 @@
# $FreeBSD$
PORTNAME= semantik
DISTVERSION= 1.2.1
PORTREVISION= 1
DISTVERSION= 1.2.2
CATEGORIES= deskutils kde
MASTER_SITES= https://waf.io/

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1546516843
SHA256 (semantik-1.2.1.tar.bz2) = 33901309d2127ba45e8e9c345729e9565eea7a45952b7bfdf22ef3838dfb0e84
SIZE (semantik-1.2.1.tar.bz2) = 617115
TIMESTAMP = 1562400272
SHA256 (semantik-1.2.2.tar.bz2) = 85d1316aac1c49b667608d032c09fec299e6c3f29be94f5ed911276601849e8a
SIZE (semantik-1.2.2.tar.bz2) = 618183

View File

@ -2,8 +2,7 @@
# $FreeBSD$
PORTNAME= tumbler
PORTVERSION= 0.2.4
PORTREVISION= 2
PORTVERSION= 0.2.5
CATEGORIES= deskutils xfce
MASTER_SITES= XFCE
PKGNAMEPREFIX= xfce4-

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1558125774
SHA256 (xfce4/tumbler-0.2.4.tar.bz2) = 0ff497e13f9f9322112cb7707918dd8970e405447f0c92dac40ec3d659e5b6a6
SIZE (xfce4/tumbler-0.2.4.tar.bz2) = 560604
TIMESTAMP = 1561895956
SHA256 (xfce4/tumbler-0.2.5.tar.bz2) = 6447697a861a4854f18348a4dc6aa8b7903a0f22c52350b793fab6bc6968d459
SIZE (xfce4/tumbler-0.2.5.tar.bz2) = 563993

View File

@ -55,6 +55,7 @@ share/dbus-1/services/org.xfce.Tumbler.Thumbnailer1.service
%%NLS%%share/locale/he/LC_MESSAGES/tumbler.mo
%%NLS%%share/locale/hr/LC_MESSAGES/tumbler.mo
%%NLS%%share/locale/hu/LC_MESSAGES/tumbler.mo
%%NLS%%share/locale/hy_AM/LC_MESSAGES/tumbler.mo
%%NLS%%share/locale/id/LC_MESSAGES/tumbler.mo
%%NLS%%share/locale/is/LC_MESSAGES/tumbler.mo
%%NLS%%share/locale/it/LC_MESSAGES/tumbler.mo

View File

@ -32,6 +32,7 @@
SUBDIR += R-cran-crayon
SUBDIR += R-cran-data.table
SUBDIR += R-cran-doParallel
SUBDIR += R-cran-ellipsis
SUBDIR += R-cran-evaluate
SUBDIR += R-cran-fansi
SUBDIR += R-cran-foreach
@ -92,6 +93,7 @@
SUBDIR += aarch64-none-elf-gcc
SUBDIR += aarch64-xtoolchain-gcc
SUBDIR += abi-compliance-checker
SUBDIR += abseil
SUBDIR += ace
SUBDIR += ace+tao-doc
SUBDIR += acsccid
@ -955,6 +957,7 @@
SUBDIR += hs-mueval
SUBDIR += hs-old-locale
SUBDIR += hs-old-time
SUBDIR += hs-profiteur
SUBDIR += hs-random
SUBDIR += hs-setlocale
SUBDIR += hs-shake
@ -1141,6 +1144,7 @@
SUBDIR += libchipcard
SUBDIR += libcidr
SUBDIR += libcii
SUBDIR += libcircllhist
SUBDIR += libcjson
SUBDIR += libclc
SUBDIR += libcli

View File

@ -0,0 +1,19 @@
# $FreeBSD$
PORTNAME= ellipsis
PORTVERSION= 0.2.0.1
CATEGORIES= devel
DISTNAME= ${PORTNAME}_${PORTVERSION}
MAINTAINER= tota@FreeBSD.org
COMMENT= Powerful tool for extending functions
LICENSE= GPLv3
CRAN_DEPENDS= R-cran-rlang>=0.3.0:devel/R-cran-rlang
BUILD_DEPENS= ${CRAN_DEPENDS}
RUN_DEPENDS= ${CRAN_DEPENDS}
USES= cran:auto-plist,compiles
.include <bsd.port.mk>

View File

@ -0,0 +1,3 @@
TIMESTAMP = 1562400004
SHA256 (ellipsis_0.2.0.1.tar.gz) = 0e6528c5e8016c3617cc1cfcdb5a4bfeb073e0bd5ea76b43e56b0c3208a0a943
SIZE (ellipsis_0.2.0.1.tar.gz) = 7045

View File

@ -0,0 +1,6 @@
The ellipsis is a powerful tool for extending functions. Unfortunately
this power comes at a cost: misspelled arguments will be silently
ignored. The ellipsis package provides a collection of functions
to catch problems and alert the user.
WWW: https://cran.r-project.org/web/packages/ellipsis/

Some files were not shown because too many files have changed in this diff Show More
--- schematic/scheme/gschem/action.scm.orig 2018-12-11 19:24:41 UTC
+++ schematic/scheme/gschem/action.scm
@@ -1,6 +1,7 @@
;; Lepton EDA Schematic Capture
;; Scheme API
;; Copyright (C) 2013 Peter Brett <peter@peter-b.co.uk>
+;; Copyright (C) 2017-2019 Lepton EDA Contributors
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -21,11 +22,10 @@
#:use-module (gschem core gettext)
#:use-module (gschem window)
#:use-module (gschem hook)
+ #:use-module (geda log)
#:use-module (ice-9 optargs)
#:export-syntax (define-action))
-(or (defined? 'define-syntax)
- (use-modules (ice-9 syncase)))
(define last-action (make-fluid))
(define current-action-position (make-fluid))
@@ -33,18 +33,25 @@
;; Define an eval-in-currentmodule procedure
(define (eval-cm expr) (eval expr (current-module)))
;; Evaluates a gschem action. A gschem action is expected to be a
;; symbol naming a thunk variable in the current module.
;;
;; The special-case symbol repeat-last-command causes the last action
;; executed to be repeated.
(define-public (eval-action! action)
(define (invalid-action-error)
- (error (_ "~S is not a valid gschem action.") action))
+ (log! 'warning (_ "[~A] is not a valid lepton-schematic action.") action))
+ (define (no-last-action-error)
+ (log! 'message (_ "There is no last action to repeat.")))
(define (eval-action!/recursive a)
(cond
+ ;; The action is #f when the user hits "." (repeat last action)
+ ;; and there is no last action to repeat.
+ ((eq? a #f)
+ (no-last-action-error))
+
;; Handle repeat-last-command
((equal? 'repeat-last-command a)
;; N.b. must call eval-action! rather than
@@ -107,29 +114,30 @@
;; The action is a magical procedure that does nothing but call
;; eval-action! *on itself*. This allows you to invoke an action
;; just by calling it like a normal function.
- (letrec ((action (lambda () (eval-action! action))))
+ (let ((unique-tag (list #f)))
+ (letrec ((action (case-lambda
+ (() (eval-action! action))
+ ((x) unique-tag))))
- ;; The action data is stored in procedure properties -- most
- ;; importantly, the actual thunk that the action wraps
- (let ((sp! (lambda (k v) (set-procedure-property! action k v))))
- (sp! 'gschem-cookie %cookie)
- (sp! 'gschem-thunk thunk)
- (sp! 'gschem-properties '()))
+ ;; The action data is stored in procedure properties -- most
+ ;; importantly, the actual thunk that the action wraps
+ (let ((sp! (lambda (k v) (set-procedure-property! action k v))))
+ (sp! 'gschem-cookie %cookie)
+ (sp! 'gschem-thunk thunk)
+ (sp! 'gschem-properties '()))
- ;; Deal with any properties. props should contain arguments in
- ;; pairs, where the first element of each pair is a keyword naming
- ;; a procedure property (e.g. #:icon) and the second element in
- ;; the corresponding value (e.g. "insert-text").
- (let loop ((lst props))
- (and (< 1 (length lst))
- (set-action-property! action
- (keyword->symbol (list-ref lst 0))
- (list-ref lst 1))
- (loop (list-tail lst 2))))
-
-
+ ;; Deal with any properties. props should contain arguments in
+ ;; pairs, where the first element of each pair is a keyword naming
+ ;; a procedure property (e.g. #:icon) and the second element in
+ ;; the corresponding value (e.g. "insert-text").
+ (let loop ((lst props))
+ (and (< 1 (length lst))
+ (set-action-property! action
+ (keyword->symbol (list-ref lst 0))
+ (list-ref lst 1))
+ (loop (list-tail lst 2))))
- action))
+ action)))
(define (action-thunk action)
(procedure-property action 'gschem-thunk))

View File

@ -1,7 +1,7 @@
# $FreeBSD$
PORTNAME= fldigi
PORTVERSION= 4.1.04
PORTVERSION= 4.1.05
CATEGORIES= comms hamradio
MASTER_SITES= SF/${PORTNAME}/${PORTNAME}

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1560983163
SHA256 (fldigi-4.1.04.tar.gz) = 89c19c349eaf04cd3bab94df89cdaa9d4ad8b1bc50871d3f8be1175ab237bb45
SIZE (fldigi-4.1.04.tar.gz) = 4689833
TIMESTAMP = 1562182762
SHA256 (fldigi-4.1.05.tar.gz) = 53f6f895f1a366d84e5e9844d1639ecf16886c4b68878e32751c81f12a9f0880
SIZE (fldigi-4.1.05.tar.gz) = 4636043

View File

@ -11,6 +11,7 @@
SUBDIR += ascii2binary
SUBDIR += asr10
SUBDIR += base64
SUBDIR += base91
SUBDIR += bibtexconv
SUBDIR += bsdconv
SUBDIR += btoa

View File

@ -0,0 +1,24 @@
# $FreeBSD$
PORTNAME= base91
PORTVERSION= 0.6.0
CATEGORIES= converters
MASTER_SITES= SF/${PORTNAME}/basE91/${PORTVERSION}/
MAINTAINER= takefu@airport.fm
COMMENT= Utility to encode and decode base91 files
LICENSE= BSD3CLAUSE
LICENSE_FILE= ${WRKSRC}/LICENSE
# INSTALL_DATA is only used to install documentation related files
MAKE_ENV+= INSTALL_DATA="${INSTALL_MAN}" INSTALL_PROGRAM="${INSTALL_PROGRAM}"
PLIST_FILES= bin/b91dec \
bin/b91enc \
bin/base91 \
man/man1/b91dec.1.gz \
man/man1/b91enc.1.gz \
man/man1/base91.1.gz
.include <bsd.port.mk>

View File

@ -0,0 +1,3 @@
TIMESTAMP = 1559031250
SHA256 (base91-0.6.0.tar.gz) = 02cfae7322c1f865ca6ce8f2e0bb8d38c8513e76aed67bf1c94eab1343c6c651
SIZE (base91-0.6.0.tar.gz) = 15009

View File

@ -0,0 +1,35 @@
@@ -33,18 +33,25 @@
;; Define an eval-in-currentmodule procedure
(define (eval-cm expr) (eval expr (current-module)))
-;; Evaluates a gschem action. A gschem action is expected to be a
+;; Evaluates a lepton-schematic action. An action is expected to be a
;; symbol naming a thunk variable in the current module.
;;